@@ -16,7 +16,7 @@ BEGIN
 
     @ISA = 'Exporter';
 
-    $VERSION = '0.76';
+    $VERSION = '0.77';
 
     my %tags =
         ( types =>
@@ -217,7 +217,7 @@ it is considered optional.
 =head2 Type Validation
 
 This module supports the following simple types, which can be
-L<exported as constants|EXPORT>:
+L<exported as constants|/EXPORT>:
 
 =over 4
 
@@ -699,8 +699,8 @@ figures out how to do this, please let me know.
 =head1 SUPPORT
 
 For now, support questions should be sent to Dave at autarch@urth.org.
-The CVS repository is on Savannah at
-https://savannah.nongnu.org/projects/p-v-perl/.
+
+The code repository is at https://svn.urth.org/svn/Params-Validate/
 
 =head1 SEE ALSO
 
